package cn.ibizlab.r7.runtime.org.core.r7rt_org.service.impl;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.transaction.annotation.Transactional;
import cn.ibizlab.r7.runtime.org.core.r7rt_org.domain.OrgUser;
import cn.ibizlab.r7.runtime.org.core.r7rt_org.filter.OrgUserSearchContext;
import cn.ibizlab.r7.runtime.org.core.r7rt_org.service.IOrgUserService;
import cn.ibizlab.r7.runtime.org.core.r7rt_org.service.logic.IOrgUserSyncUserLogic;
import org.springframework.beans.factory.annotation.Autowired;
import cn.ibizlab.r7.runtime.org.util.SearchResult;

/**
 * 实体[组织用户] 服务对象接口实现
 */
@Service
public class OrgUserServiceImpl implements IOrgUserService {

    @Autowired
    cn.ibizlab.r7.runtime.org.core.repository.OrgUserRepository orgUserRepository;

    @Autowired
    private IOrgUserSyncUserLogic syncuserLogic ;

    @Override
    @Transactional
    public boolean create(OrgUser orguser) {
        syncuserLogic.execute(orguser);
        boolean bOk = false ;
        cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER = orgUserRepository.convert2PO(orguser,null);
        bOk = orgUserRepository.create(t_ORGUSER);
        orgUserRepository.convert2Domain(t_ORGUSER,orguser);


        return bOk ;
    }

    @Override
    @Transactional
    public boolean save(OrgUser orguser) {
        if(orguser.getOrgUserId()==null){
    		return create(orguser);
    	}else{
            if(this.get(orguser.getOrgUserId())!=null){
    			return update(orguser);
    		}
    		return create(orguser);
    	}
    }

    @Override
    @Transactional
    public boolean update(OrgUser orguser) {
        syncuserLogic.execute(orguser);
        boolean bOk = false ;
        cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER = orgUserRepository.convert2PO(orguser,null);
        bOk = orgUserRepository.update(t_ORGUSER);
        orgUserRepository.convert2Domain(t_ORGUSER,orguser) ;
        return bOk ;
    }

    @Override
    @Transactional
    public boolean remove(String orguserid) {
        boolean bOk = false ;

        OrgUser _orgUser = this.get(orguserid);
        bOk = orgUserRepository.remove(orguserid);

        return bOk ;
    }

    @Override
    @Transactional
    public OrgUser get(String orguserid) {
        cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser _t_ORGUSER = orgUserRepository.get(orguserid);
        if(_t_ORGUSER == null)
            return null ;

        OrgUser _orgUser = orgUserRepository.convert2Domain(_t_ORGUSER,null) ;

        return _orgUser;
    }

    @Override
    @Transactional
    public OrgUser get(OrgUser orguser) {
        cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER = orgUserRepository.get(orguser.getOrgUserId());
        orgUserRepository.convert2Domain(t_ORGUSER,orguser);
        return orguser;
    }

    @Override
    public boolean checkKey(OrgUser orguser) {
        return true;
    }

    @Override
    public OrgUser getDraft(OrgUser orguser) {
        return orguser;
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<OrgUser> searchDefault(OrgUserSearchContext context) {
        List<OrgUser> list = new ArrayList<OrgUser>();
        Page<cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser> t_ORGUSERs = orgUserRepository.searchDefault(context) ;
        for(cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER : t_ORGUSERs){
            list.add(orgUserRepository.convert2Domain(t_ORGUSER,null));
        }
        return new PageImpl<OrgUser>(list, context.getPageable(), t_ORGUSERs.getTotalElements());
    }


    /**
     * 根据组织查询
     */
    @Override
    public Page<OrgUser> selectByOrg(String orgid){
        OrgUserSearchContext context = new OrgUserSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgid)){
            cn.ibizlab.r7.runtime.org.util.SearchFieldFilter fieldFilter=new cn.ibizlab.r7.runtime.org.util.SearchFieldFilter();
            fieldFilter.setParam("orgid");
            fieldFilter.setCondition(cn.ibizlab.r7.runtime.org.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgid);
            context.getCondition().add(fieldFilter);
        }
        List<OrgUser> list = new ArrayList<OrgUser>();
        Page<cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser> t_ORGUSERs = orgUserRepository.searchDefault(context) ;
        for(cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER : t_ORGUSERs){
            list.add(orgUserRepository.convert2Domain(t_ORGUSER,null));
        }
        return new PageImpl<OrgUser>(list, context.getPageable(), t_ORGUSERs.getTotalElements());
    }

    /**
     * 根据组织查询
     */
    @Override
    public List<OrgUser> selectByOrg2(String orgid){
        OrgUserSearchContext context = new OrgUserSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgid)){
            cn.ibizlab.r7.runtime.org.util.SearchFieldFilter fieldFilter=new cn.ibizlab.r7.runtime.org.util.SearchFieldFilter();
            fieldFilter.setParam("orgid");
            fieldFilter.setCondition(cn.ibizlab.r7.runtime.org.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgid);
            context.getCondition().add(fieldFilter);
        }
        List<OrgUser> list = new ArrayList<OrgUser>();
        Page<cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser> t_ORGUSERs = orgUserRepository.searchDefault(context) ;
        for(cn.ibizlab.r7.runtime.org.core.repository.po.OrgUser t_ORGUSER : t_ORGUSERs){
            list.add(orgUserRepository.convert2Domain(t_ORGUSER,null));
        }
        return list;
    }




}
